@@ -21,13 +21,13 @@
 
 #include <libgda/gda-config.h>
 #include <libgda/gda-data-model-array.h>
-#include <bonobo/bonobo-i18n.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtkvbbox.h>
 #include <libgnomedb/gnome-db-grid.h>
+#include <libgnomedb/gnome-db-i18n.h>
 #include <libgnomedb/gnome-db-util.h>
 #include "provider-config.h"
 
