@@ -28,7 +28,7 @@
 #include <libgnomedb/gnome-db-dsn-config-druid.h>
 #include <libgnomedb/gnome-db-provider-selector.h>
 #include <libgnomedb/gnome-db-util.h>
-#include <bonobo/bonobo-i18n.h>
+#include "gnome-db-i18n.h"
 
 #define PARENT_TYPE GNOME_TYPE_DRUID
 
