@@ -48,14 +48,22 @@ struct _GnomeDbGrid {
 struct _GnomeDbGridClass {
 	GtkVBoxClass parent_class;
 
+	/* signals */
 	void (* row_selected) (GnomeDbGrid *grid, gint row);
 	void (* selection_cleared) (GnomeDbGrid *grid);
+	void (* double_clicked) (GnomeDbGrid *grid, gint row);
+	void (* create_popup_menu) (GnomeDbGrid *grid, GtkWidget *menu);
 };
 
 GType            gnome_db_grid_get_type (void);
 GtkWidget       *gnome_db_grid_new (void);
 GtkWidget       *gnome_db_grid_new_with_model (GdaDataModel *model);
 
+const gchar     *gnome_db_grid_get_title (GnomeDbGrid *grid);
+void             gnome_db_grid_set_title (GnomeDbGrid *grid, const gchar *title);
+gboolean         gnome_db_grid_get_show_title (GnomeDbGrid *grid);
+void             gnome_db_grid_set_show_title (GnomeDbGrid *grid, gboolean show);
+
 GdaDataModel    *gnome_db_grid_get_model (GnomeDbGrid *grid);
 void             gnome_db_grid_set_model (GnomeDbGrid *grid, GdaDataModel *model);
 GList           *gnome_db_grid_get_selection (GnomeDbGrid *grid);
@@ -71,6 +79,10 @@ void             gnome_db_grid_set_selection_mode (GnomeDbGrid *grid,
 void             gnome_db_grid_hide_column_titles (GnomeDbGrid *grid);
 void             gnome_db_grid_show_column_titles (GnomeDbGrid *grid);
 
+gpointer         gnome_db_grid_get_row_data (GnomeDbGrid *grid, gint row);
+void             gnome_db_grid_set_row_data (GnomeDbGrid *grid, gint row, gpointer data);
+gint             gnome_db_grid_find_row_from_data (GnomeDbGrid *grid, gpointer data);
+
 G_END_DECLS
 
 #endif
