@@ -28,6 +28,7 @@
 G_BEGIN_DECLS
 
 #define GNOME_DB_STOCK_AGGREGATES         "gnome-db-aggregates"
+#define GNOME_DB_STOCK_COMMIT             "gnome-db-commit"
 #define GNOME_DB_STOCK_CONNECT            "gnome-db-connect"
 #define GNOME_DB_STOCK_DISCONNECT         "gnome-db-disconnect"
 #define GNOME_DB_STOCK_DATABASE           "gnome-db-database"
@@ -35,6 +36,7 @@ G_BEGIN_DECLS
 #define GNOME_DB_STOCK_NO_TRANSACTION     "gnome-db-no-transaction"
 #define GNOME_DB_STOCK_PROCEDURES         "gnome-db-procedures"
 #define GNOME_DB_STOCK_QUERY              "gnome-db-query"
+#define GNOME_DB_STOCK_ROLLBACK           "gnome-db-rollback"
 #define GNOME_DB_STOCK_SEQUENCES          "gnome-db-sequences"
 #define GNOME_DB_STOCK_SQL                "gnome-db-sql"
 #define GNOME_DB_STOCK_TABLES             "gnome-db-tables"
